<?php
/*
 * Public Domain
 */
if (!defined('NOT_ACCESSED_DIRECTLY')) exit('This file may not be directly accessed');

//Your module's directory needs to contain a PHP file named module_code.php. This file
//should contain a PHP class definition, which should contain your module's program
//code.

//The class name you use MUST match your module's directory name.

//Your class should either extend the module_base_class, or else extend another module
//that extends the module_base_class.
//If you extend another module, you must list that module as a dependancy in your
//description.yaml file. The CMS will then check if the module you are extending can be
//run and include it for you each time the code your module is included; you do not
//need to use "include" or "require" in your code to include the module you are
//extending.


class example_module_5 extends module_base_class {
	
	//Your fillAdminBox() method is called by the CMS whenever an Admin opens one of
	//your Admin Boxes, or an Admin Box that you have added new fields into.
	public function fillAdminBox($path, $settingGroup, &$box, &$fields, &$values) {
	
		//You should always use an if () or a switch () statement on the path,
		//to ensure that you are running code for the correct Admin Box.
		switch ($path) {
			case 'example_module_4__animal':
				
				//When displaying an existing animal in an Admin Box, try to load its
				//classification
				if ($box['key']['id']) {
					$values['example_module_5__classification'] =
						getRow(
							EXAMPLE_MODULE_5_PREFIX. 'animals_classification',
							'classification',
							$box['key']['id']);
				}
				
				break;
		}
	}
	
	//Your saveAdminBox() method is called by the CMS whenever an Admin tries to
	//save one of your Admin Boxes. You should create/update any rows in the database
	//that you need to save the information that an Admin as entered.
	public function saveAdminBox($path, $settingGroup, &$box, &$fields, &$values, $changes) {
		
		//You should always use an if () or a switch () statement on the path,
		//to ensure that you are running code for the correct Admin Box.
		switch ($path) {
			case 'example_module_4__animal':
				if (!empty($box['tabs']['details']['edit_mode']['on'])) {
					
					//Save the value of the classification field in the animals_classification table
					if ($box['key']['id']) {
						
						$details = array();
						if (!$details['classification'] = $values['example_module_5__classification']) {
							$details['classification'] = null;
						}
						
						setRow(
							EXAMPLE_MODULE_5_PREFIX. 'animals_classification',
							$details,
							$box['key']['id']);
					}
				}
				
				break;
		}
	}
	
	//Some signal handlers
	public static function exampleModuleEventAnimalDeleted($id) {
		
		//Listen for the 'animal deleted' signal, and tidy up any data from the
		//animals_classification table that belonged to the deleted animal
		deleteRow(EXAMPLE_MODULE_5_PREFIX. 'animals_classification', $id);
	}
	
	public static function exampleModuleEventAnimalCreated($id) {
		
		//Send email notifications using the Email Template Manager, if notifications
		//are enabled in the site settings.
		if (setting('example_module_5__send_notification_email')
		 && setting('example_module_5__notification_email_address')
		 && setting('example_module_5__notification_email_template')
		 && inc('zenario_email_template_manager')) {
			
			//Wait until after any other changes are finished before sending the email
			register_shutdown_function(
				array('example_module_5', 'exampleModuleEventAnimalCreatedPart2'),
				$id);
		}
	}
	
	public static function exampleModuleEventAnimalCreatedPart2($id) {
		//Check to see if we can load this animal's details
		if ($details = example_module_4::animalDetails($id)) {
			
			//Add the classification if it exists
			$details['classification'] = 
				getRow(
					EXAMPLE_MODULE_5_PREFIX. 'animals_classification',
					'classification',
					$id);
			
			//Add URLs to the website, and to the animal in Storekeeper
			$details['cms_url'] = absCMSDirURL();
			$details['management_url'] =
				absCMSDirURL().
				'zenario/admin/storekeeper.php#example_module_4/panels/animals//'. $id;
			
			//Send the chosen email template using the Email Template Manager
			zenario_email_template_manager::sendEmailsUsingTemplate(
				setting('example_module_5__notification_email_address'),
				setting('example_module_5__notification_email_template'),
				$details);
		}
	}
}